@@ -19,11 +19,27 @@ class Lexer(object):
                          '@': self.handle_empty_jinja,
                          '!': self.handle_doctype}
 
+    def join_src_lines(self):
+        src_iter = iter(self.src)
+        lines = []
+        while True:
+            line = next(src_iter)
+            if line.rstrip().endswith('\\'):
+                lines.append(line.rstrip()[:-1])
+            else:
+                if lines:
+                    lines.append(line.strip())
+                    yield ' '.join(lines)
+                    lines = []
+                else:
+                    yield line
+
+
     def __call__(self):
         """
         Tokenizes `self.src` and yields `Token` objects..
         """
-        for line in self.src:
+        for line in self.join_src_lines():
             self.lineno += 1
             # Ignore blank lines and comments.
             stripped_line = line.strip()
